@@ -122,12 +122,12 @@ class PQIndexer(Indexer):
         idxdat['dsub'] = dsub
         idxdat['centroids'] = [None for q in range(nsubq)]
 
-        logging.info("Building codebooks in subspaces - BEGIN\n")
+        logging.info("Building codebooks in subspaces - BEGIN")
         for q in range(nsubq):
-            logging.info("\tsubspace %d/%d:\n" % (q, nsubq))
+            logging.info("\tsubspace %d/%d:" % (q, nsubq))
             vs = np.require(vals[:, q*dsub:(q+1)*dsub], requirements='C')
             idxdat['centroids'][q] = kmeans(vs, ksub, niter=100)
-        logging.info("Building codebooks in subspaces - DONE\n")
+        logging.info("Building codebooks in subspaces - DONE")
 
         self.idxdat = idxdat
 
